@@ -1,16 +1,19 @@
 """
-Things that relies on LLVM library
+Things that rely on the LLVM library
 """
-from __future__ import print_function, absolute_import
-
 from .dylib import *
 from .executionengine import *
 from .initfini import *
 from .linker import *
 from .module import *
 from .options import *
+from .newpassmanagers import *
 from .passmanagers import *
 from .targets import *
 from .transforms import *
 from .value import *
+from .typeref import *
 from .analysis import *
+from .object_file import *
+from .context import *
+from .orcjit import *
